######################
imagedata-formats-biff
######################

|Docs Badge| |buildstatus|  |coverage| |pypi|


Imagedata plugin for biff image files.


.. |Docs Badge| image:: https://readthedocs.org/projects/imagedata-formats-biff/badge/
    :alt: Documentation Status
    :scale: 100%
    :target: https://imagedata-formats-biff.readthedocs.io

.. |buildstatus| image:: https://github.com/erling6232/imagedata-formats-biff/actions/workflows/ci.yml/badge.svg
    :target: https://github.com/erling6232/imagedata-formats-biff/actions?query=branch%3Amaster
    :alt: Build Status

.. _buildstatus: https://github.com/erling6232/imagedata-formats-biff/actions

.. |coverage| image:: https://codecov.io/gh/erling6232/imagedata-formats-biff/branch/master/graph/badge.svg?token=GT9KZV2TWT
    :alt: Coverage
    :target: https://codecov.io/gh/erling6232/imagedata-formats-biff

.. |pypi| image:: https://img.shields.io/pypi/v/imagedata-formats-biff.svg
    :target: https://pypi.python.org/pypi/imagedata-formats-biff
    :alt: PyPI Version

